#!/usr/bin/env python

import os
import os.path
import re

license = """/*
    This file is part of Android File Transfer For Linux.
    Copyright (C) 2015-2020  Vladimir Menshakov

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2.1 of the License,
    or (at your option) any later version.

    This library is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this library; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

"""

license_re = re.compile(r'^/\*.*?\*/\s+', re.M | re.S)

for root, dirs, files in os.walk('.'):
	if root == "./mtp/backend/linux/usb/linux":
		continue

	for file in files:
		name, ext = os.path.splitext(file)
		if ext != '.h' and ext != '.cpp':
			continue
		if name == "arg_lexer.l":
			continue

		fname = os.path.join(root, file)
		with open(fname) as f:
			data = f.read()

		if license_re.match(data):
			data = license_re.sub(license, data, 1)
		else:
			data = license + data

		with open(fname, 'w') as f:
			f.write(data)



#!/usr/bin/python3

#!/usr/bin/env python

import os
import os.path
import re

guard_re = re.compile(r'#ifndef\s+(\w+)\n#define\s+(\w+)', re.M | re.S)
base_dir = os.path.dirname(os.path.realpath(__file__))
clean_re = re.compile(r'[^\w]')
print(base_dir)

for root, dirs, files in os.walk('.'):
	root = os.path.relpath(root, base_dir)
	if (root[0] == '.' and len(root) > 1) or root.startswith("build"):
		dirs[:] = []
		continue
	if root == "mtp/backend/linux/usb/linux":
		continue

	for file in files:
		name, ext = os.path.splitext(file)
		if ext != '.h' or name == "arg_lexer.l" or name.endswith(".values"):
			continue

		fname = os.path.join(root, file)
		with open(fname) as f:
			data = f.read()

		guard = 'AFTL_' + clean_re.sub('_', os.path.relpath(os.path.join(root, file), base_dir)).upper()

		def replace_guard(m):
			return "#ifndef %s\n#define %s" %(guard, guard)

		data, n = guard_re.subn(replace_guard, data, count=1)
		if n == 0:
			print("missing guard in %s" %file)
		else:
			with open(fname, 'w') as f:
				f.write(data)




#!/usr/bin/python3

# -*- coding: utf-8 -*-
"""
hierarchical prompt usage example
"""
from __future__ import print_function, unicode_literals
from PyInquirer import style_from_dict, Token, prompt, Separator

import aftl

def get_storage_prompt(session, s):
	info = session.get_storage_info(s)
	name = info.StorageDescription
	if not name:
		name = repr(s)
	return { 'name': name, 'value': s }

def get_storage(session):
	storage_prompt = {
		'type': 'list',
		'name': 'storage',
		'message': 'Select storage',
		'choices': list(map(lambda s: get_storage_prompt(session, s), session.get_storage_ids())) + [{'name': 'Quit', 'value': None}]
	}
	answers = prompt(storage_prompt)
	return answers.get('storage')

def get_object_prompt(session, object):
	info = session.get_object_info(object)
	name = info.Filename
	if info.ObjectFormat == aftl.ObjectFormat.Association:
		name += '/'
	return {'name': name, 'value': (object, info.ObjectFormat) }

def get_object(session, storage, parent):
	objects = session.get_object_handles(storage, aftl.ObjectFormat.Any, parent)
	object_prompt = {
		'type': 'list',
		'name': 'object',
		'message': 'Browse objects',
		'choices': [{'name': '..', 'value': (None, None) }] + \
			list(map(lambda o: get_object_prompt(session, o), objects))
	}
	answers = prompt(object_prompt)
	return answers.get('object')

def get_object_action(session):
	action_prompt = {
		'type': 'expand',
		'name': 'action',
		'message': 'Object Action (press h for help)',
		'choices': [
			{ 'key': 'b', 'name': 'Back', 'value': 'back' },
			Separator(),
			{ 'key': 'd', 'name': 'Download', 'value': 'download' },
		]
	}
	return prompt(action_prompt).get('action')

def main():
	session = aftl.Device.find_first().open_session()
	while True:
		storage = get_storage(session)
		if storage is None:
			break

		path = [aftl.Session.Root]
		while path:
			object, type = get_object(session, storage, path[-1])
			if type == aftl.ObjectFormat.Association:
				path.append(object)
				continue

			if object is None:
				path.pop()
				continue

			while True:
				action = get_object_action(session)
				if action == 'back':
					break

				if action == 'download':
					name = session.get_object_string_property(object, aftl.ObjectProperty.ObjectFilename)
					with open(name, "wb") as f:
						session.get_object(object, f)


if __name__ == '__main__':
	main()
